@@ -296,6 +296,13 @@ menustruct FileMenu[] = {
 	{"Execute script", action(getfile, Number(SCRIPT))},
 	{"Write Xcircuit PS (W)", action(outputpopup, NULL)},
 	{" ", noaction},
+#ifdef USE_WIN32_COM
+	{"Execute Windows script (JScript/VBScript)", action(getfile, Number(COMSCRIPT))},
+#ifdef USE_WIN32_DOTNET
+	{"Load .NET plugin", action(getfile, Number(COMDOTNET))},
+#endif
+	{" ", noaction},
+#endif
 	{"Add To Library", action(getlib, NULL)},
 	{"Load New Library", action(getuserlib, NULL)},
 	{"Save Library", action(savelibpopup, Number(0))},
