@@ -12,14 +12,18 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
+#endif
 
 #ifdef TCL_WRAPPER 
 #include <tk.h>
 #else
+#ifndef XC_WIN32
 #include "Xw/Xw.h"
 #endif
+#endif
 
 /*----------------------------------------------------------------------*/
 /* Local includes							*/
@@ -42,7 +46,9 @@ extern Tcl_Interp *xcinterp;
 #endif
 extern Globaldata xobjs;
 extern Clientdata areastruct;
+#ifndef TCL_WRAPPER
 extern Widget     menuwidgets[];
+#endif
 extern short textpos, textend;
 extern char _STR[150];
 
@@ -71,10 +77,14 @@ u_char param_select[] = {
 };
 
 #ifdef TCL_WRAPPER
+#ifndef _MSC_VER
 xcWidget *param_buttons[] = {
    /* To be done---map buttons to Tk_Windows! */
 };
 #else
+xcWidget *param_buttons[];
+#endif
+#else
 Widget *param_buttons[] = {
    &ParametersNumericButton,		/* P_NUMERIC */
    &ParametersSubstringButton,		/* P_SUBSTRING */
@@ -2095,6 +2105,7 @@ void removeparams(objectptr thisobj)
 	 free(ops->parameter.expr);
       free(ops);
    }
+   thisobj->params = NULL;
 }
 
 /*-----------------------------------------------------------------------*/
